@@ -113,9 +113,8 @@ class ErrorFormulaExtractor:
             attributes={"survey_tool_id": survey_tool.survey_tool_id}
         )['DP_TOOL_TERM']
 
-        # # make all sequences_no in the error_codes list float
-        # for error_code in error_codes:
-        #     error_code["sequence_no"] = float(error_code["sequence_no"])
+        # sort the error codes by sequence_no
+        error_codes = sorted(error_codes, key=lambda d: int(float(d['sequence_no'])))
 
         error_terms = {}
         for code in error_codes:
@@ -123,86 +122,68 @@ class ErrorFormulaExtractor:
             term_name = code["term_name"]
             existing_term = error_terms.get(term_name)
 
-            term = self.extract_single_term(code, existing_term)
+            term = extract_single_term(code, existing_term)
 
             error_terms[term_name] = term
 
-        terms = list(error_terms.values())
-        survey_tool.error_terms = sorted(terms, key=lambda d: d.sequence_no)
+        survey_tool.error_terms = list(error_terms.values())
+        survey_tool.sort_error_terms()
 
-    def extract_single_term(self, code: dict, existing_error_term: Optional[ErrorTerm] = None) -> ErrorTerm:
-        if "xcl" in code["term_name"].lower():
-            code["c_formula"] = self.extract_xcl_formula(code["c_formula"])
+        return survey_tool
 
-        tie_type = Propagation.extract_tie_type(code["tie_type"])
-        vector = self.extract_vector_type(code)
-        mag = float(code["c_value"])
-        if code["c_units"] in ["d", "dnt"]:
-            mag = mag * DEGREE_TO_RAD
 
-        func, func_args, func_str = function_builder(code["c_formula"], code["term_name"].lower().replace("-", "_"))
+def extract_single_term(code: dict, existing_error_term: Optional[ErrorTerm] = None) -> ErrorTerm:
+    if "xcl" in code["term_name"].lower():
+        code["c_formula"] = extract_xcl_formula(code["c_formula"])
 
-        error_term = ErrorTerm(
-            sequence_no=int(float(code["sequence_no"])),
-            term_name=code["term_name"],
+    tie_type = Propagation.extract_tie_type(code["tie_type"])
+    vector = VectorType.extract_vector_type(code["vector_type"])
+    mag = float(code["c_value"])
+    if code["c_units"] in ["d", "dnt"]:
+        mag = mag * DEGREE_TO_RAD
 
-            formula=[code["c_formula"]],
-            error_function=[func],
-            arguments=[func_args],
-            func_string=[func_str],
+    func, func_args, func_str = function_builder(code["c_formula"], code["term_name"].lower().replace("-", "_"))
 
-            magnitude=[mag],
-            units=[code["c_units"]],
-            vector_type=[vector],
-            tie_type=[tie_type],
-        )
+    error_term = ErrorTerm(
+        sequence_no=int(float(code["sequence_no"])),
+        term_name=code["term_name"],
 
-        if existing_error_term:
-            error_term = existing_error_term + error_term
+        formula=[code["c_formula"]],
+        error_function=[func],
+        arguments=[func_args],
+        func_string=[func_str],
 
-        return error_term
+        magnitude=[mag],
+        units=[code["c_units"]],
+        vector_type=[vector],
+        tie_type=[tie_type],
+    )
 
-    def extract_vector_type(self, code: dict) -> VectorType:
+    if existing_error_term:
+        error_term = existing_error_term + error_term
 
-        terms = VectorType.get_object()
+    return error_term
 
-        if code["vector_type"] in terms.get("azimuth_terms"):
-            return VectorType.AZIMUTH_TERMS
 
-        if code["vector_type"] == terms.get("inclination_terms"):
-            return VectorType.INCLINATION_TERMS
+def extract_xcl_formula(formula: str) -> str:
+    """
+    This function updates the formula string from the EDM and puts it in the correct format
+    that can be used with the formula extractor
+    """
 
-        if code["vector_type"] == terms.get("depth_terms"):
-            return VectorType.DEPTH_TERMS
+    # remove swon from the formula string
+    formula = formula.replace("swon", "")
 
-        if code["vector_type"] == VectorType.LATERAL.value:
-            return VectorType.LATERAL
+    # Assigning constant XCL tortuosity of 1deg/ft
+    formula = formula.replace("tort", str(TORTUOSITY_RAD_PER_M))
 
-        if code["vector_type"] == VectorType.NA:
-            return VectorType.NA
+    # if string +swoff is in the formula
+    if "+swoff" not in formula:
+        return formula
 
-        return VectorType.DEPTH_TERMS
+    # split the formula based on swoff
+    term1, term2 = formula.split("+swoff")
+    # create the new string with max
+    formula_updated = f"max({term1}, {term2})"
 
-    @staticmethod
-    def extract_xcl_formula(formula: str) -> str:
-        """
-        This function updates the formula string from the EDM and puts it in the correct format
-        that can be used with the formula extractor
-        """
-
-        # remove swon from the formula string
-        formula = formula.replace("swon", "")
-
-        # Assigning constant XCL tortuosity of 1deg/ft
-        formula = formula.replace("tort", str(TORTUOSITY_RAD_PER_M))
-
-        # if string +swoff is in the formula
-        if "+swoff" not in formula:
-            return formula
-
-        # split the formula based on swoff
-        term1, term2 = formula.split("+swoff")
-        # create the new string with max
-        formula_updated = f"max({term1}, {term2})"
-
-        return formula_updated
+    return formula_updated
