@@ -121,7 +121,14 @@ class ToolError:
         for vector_no in range(len(vector_type)):
             # for each vector in vector_type, first, extract all arguments from the equation.
 
-            if vector_type[vector_no] == VectorType.LATERAL:
+            # FIXME: This is a temporary fix for the singularity calculation.
+            # This works for 3 ISCWSA covariances test case, but a solution needs to be find for
+            # EDM files.
+            is_in_extracted_singular_terms = next((item for item in [
+                "abxy", "abixy", "cna", "xym3", "xym3e", "xym3l", "xym4", "xym4e", "xym4l", "xcla"
+            ] if item in term.term_name.lower()), None)
+
+            if vector_type[vector_no] == VectorType.LATERAL and is_in_extracted_singular_terms:
                 sing_calc = True
 
             args = []
